==> wmx10_0.02.orig.tar.gz: wmx10.app/wmx10/wmx10.h <==
#define SERIAL_PORT "/dev/ttyS0"

#define WMX10_VERSION "0.02"

enum brightness{ zero, one, two, three, four, five, six };
enum lampNumbers { lamp1, lamp2, lamp3, lamp4, lamp5, lamp6, lamp7, lamp8 };

typedef struct img 
{
   int tlx;
   int tly;
   int brx;
   int bry;
} img_t;

img_t buttonArray[6] =
  { {12,27,28,38}, {37,27,53,38}, {12,40,29,51},
    {36,40,53,51}, {7,16,19,24}, {46,16,58,24} };

img_t buttonDownArray[6] =
  { {67,0,82,11}, {67,12,82,22}, {67,25,83,36},
    {67,38,83,49}, {67,51,79,59}, {67,62,79,69} };

img_t buttonUpArray[6] =
  { {82,0,98,11}, {82,12,98,22}, {82,25,99,36},
    {82,38,99,49}, {82,51,94,59}, {82,62,94,69} };

img_t numberArray[8] =
  { {7,67,13,76}, {13,67,19,76}, {19,67,25,76},
    {25,67,31,76}, {31,67,37,76}, {37,67,43,76},
    {43,67,48,76}, {48,67,54,76} };


img_t greenLight6 = { 0,91, 4,95  }; /* max green */
img_t greenLight5 = { 6,91,10,95  };
img_t greenLight4 = { 12,91,16,95 };
img_t greenLight3 = { 18,91,22,95 };
img_t greenLight2 = { 24,91,28,95 };
img_t greenLight1 = { 30,91,34,95 };
img_t greenLight0 = { 36,91,40,95 }; /* off */


img_t lightArray[8] =
  { {13,55,17,59}, {18,55,22,59}, {23,55,27,59},
    {28,55,31,59}, {32,55,36,59}, {37,55,41,59},
    {42,55,46,59}, {47,55,51,59} };

img_t letterArray[16] =
  { {0,80,5,88}, {6,80,11,88}, {12,80,17,88},
    {18,80,23,88}, {24,80,29,88}, {30,80,35,88},
    {36,80,41,88}, {42,80,47,88}, {48,80,53,88},
    {54,80,59,88}, {60,80,65,88}, {66,80,71,88},
    {72,80,77,88}, {78,80,83,88}, {84,80,89,88},
    {90,80,95,88} };

==> wmx10_0.03.orig.tar.gz: wmx10.app/wmx10/wmx10.h <==
#define SERIAL_PORT "/dev/ttyS0"

#define WMX10_VERSION "0.03"

enum brightness{ zero, one, two, three, four, five, six };
enum lampNumbers { lamp1, lamp2, lamp3, lamp4, lamp5, lamp6, lamp7, lamp8, 
                   lamp9, lamp10, lamp11, lamp12, lamp13, lamp14, lamp15, lamp16
		 };

typedef struct img 
{
   int tlx;
   int tly;
   int brx;
   int bry;
} img_t;

img_t buttonArray[6] =
  { {12,27,28,38}, {37,27,53,38}, {12,40,29,51},
    {36,40,53,51}, {7,16,19,24}, {46,16,58,24} };

img_t buttonDownArray[6] =
  { {67,0,82,11}, {67,12,82,22}, {67,25,83,36},
    {67,38,83,49}, {67,51,79,59}, {67,62,79,69} };

img_t buttonUpArray[6] =
  { {82,0,98,11}, {82,12,98,22}, {82,25,99,36},
    {82,38,99,49}, {82,51,94,59}, {82,62,94,69} };

img_t numberArray[10] =
  { {1,67,7,76},    /* The zero followed by 1 thru 9 */
    {7,67,13,76}, {13,67,19,76}, {19,67,25,76},
    {25,67,31,76}, {31,67,37,76}, {37,67,43,76},
    {43,67,49,76}, {49,67,55,76}, {55,67,61,76} };


img_t greenLight6 = { 0,91, 4,95  }; /* max green */
img_t greenLight5 = { 6,91,10,95  };
img_t greenLight4 = { 12,91,16,95 };
img_t greenLight3 = { 18,91,22,95 };
img_t greenLight2 = { 24,91,28,95 };
img_t greenLight1 = { 30,91,34,95 };
img_t greenLight0 = { 36,91,40,95 }; /* off */


img_t lightArray[16] =
  { {13,54,17,58}, {18,54,22,58}, {23,54,27,58},
    {28,54,31,58}, {32,54,36,58}, {37,54,41,58},
    {42,54,46,58}, {47,54,51,58},
    {13,58,17,62}, {18,58,22,62}, {23,58,27,62},
    {28,58,31,62}, {32,58,36,62}, {37,58,41,62},
    {42,58,46,62}, {47,58,51,62},
  };

img_t letterArray[16] =
  { {0,80,5,88}, {6,80,11,88}, {12,80,17,88},
    {18,80,23,88}, {24,80,29,88}, {30,80,35,88},
    {36,80,41,88}, {42,80,47,88}, {48,80,53,88},
    {54,80,59,88}, {60,80,65,88}, {66,80,71,88},
    {72,80,77,88}, {78,80,83,88}, {84,80,89,88},
    {90,80,95,88} };
